@@ -5,7 +5,7 @@ from pyramid.security import (
     Everyone,
 )
 
-from .models import User
+from . import models
 
 
 class MyAuthenticationPolicy(AuthTktAuthenticationPolicy):
@@ -26,7 +26,7 @@ class MyAuthenticationPolicy(AuthTktAuthenticationPolicy):
 def get_user(request):
     user_id = request.unauthenticated_userid
     if user_id is not None:
-        user = request.dbsession.query(User).get(user_id)
+        user = request.dbsession.query(models.User).get(user_id)
         return user
 
 def includeme(config):
